Package: conting
Type: Package
Title: Bayesian Analysis of Contingency Tables
Version: 1.7
Date: 2019-04-02
Author: Antony M. Overstall
Maintainer: Antony M. Overstall <A.M.Overstall@soton.ac.uk>
Description: Bayesian analysis of complete and incomplete contingency tables.
Depends: R (>= 2.15.0)
Imports: mvtnorm, BMS, gtools, tseries, coda
License: GPL-2
NeedsCompilation: no
Packaged: 2019-04-02 17:59:07 UTC; amo105
Repository: CRAN
Date/Publication: 2019-04-02 20:00:03 UTC
