import(mvtnorm, tseries, coda)
importFrom(gtools, combinations)
importFrom(BMS, bin2hex)
importFrom(BMS, hex2bin)
exportPattern("^[[:alpha:]]+")
S3method(plot, pval)
S3method(plot, totpop)
S3method(print, acceptrate)
S3method(print, bcct)
S3method(print, bict)
S3method(print, interprob)
S3method(print, interstat)
S3method(print, modprobs)
S3method(print, pval)
S3method(print, sbcct)
S3method(print, sbict)
S3method(print, submod)
S3method(print, totpop)
S3method(summary, bcct)
S3method(summary, bict)
importFrom("graphics", "abline", "hist", "legend", "plot", "points")
importFrom("stats", "as.formula", "coef", "dpois", "glm", "lm","model.frame", "model.matrix", "na.pass", "nlminb","poisson", "rgamma", "rpois","runif","var")
importFrom("utils", "read.table", "setTxtProgressBar","txtProgressBar", "write.table")